@@ -17,7 +17,7 @@
 #multiple alphas (OUSMA): alpha=c(0.5,0.1); sigma.sq=c(0.9,0.9); theta0=0; theta=c(1,2)
 #multiple alphas and sigmas (OUSMVA): alpha=c(0.5,0.1); sigma.sq=c(0.45,0.9); theta0=0; theta=c(1,2)
 
-OUwie.sim <- function(phy, data=NULL, simmap.tree=FALSE, alpha, sigma.sq, theta0, theta){
+OUwie.sim <- function(phy, data=NULL, simmap.tree=FALSE, scaleHeight=FALSE, alpha, sigma.sq, theta0, theta){
 
 	if(simmap.tree==FALSE){
 		#This is annoying, but the second column has to be in there twice otherwise, error.
@@ -34,21 +34,18 @@ OUwie.sim <- function(phy, data=NULL, simmap.tree=FALSE, alpha, sigma.sq, theta0
 		k<-length(levels(int.states))
 		
 		regime=matrix(rep(0,(n-1)*k), n-1, k)
-		
-		##Begins the construction of the edges matrix -- similar to the ouch format##
-		#Makes a vector of absolute times in proportion of the total length of the tree
-		branch.lengths=rep(0,(n-1))
-		branch.lengths[(ntips+1):(n-1)]=branching.times(phy)[-1]/max(branching.times(phy))
-		
+
 		#Obtain root state and internal node labels
 		root.state<-phy$node.label[1]
 		int.state<-phy$node.label[-1]
 		
 		#New tree matrix to be used for subsetting regimes
-		edges=cbind(c(1:(n-1)),phy$edge,phy$edge.length)
+		edges=cbind(c(1:(n-1)),phy$edge,nodeHeights(phy))
+		if(scaleHeight==TRUE){
+			edges[,4:5]<-edges[,4:5]/max(nodeHeights(phy))
+		}
 		edges=edges[sort.list(edges[,3]),]
-		
-		edges[,4]=branch.lengths
+
 		mm<-c(data[,1],int.state)
 		
 		regime <- matrix(0,nrow=length(mm),ncol=length(unique(mm)))
@@ -63,14 +60,13 @@ OUwie.sim <- function(phy, data=NULL, simmap.tree=FALSE, alpha, sigma.sq, theta0
 		edges=edges[sort.list(edges[,1]),]
 		
 		oldregime=root.state
-		oldtime=1
 		
 		alpha=alpha
 		sigma=sqrt(sigma.sq)
 		theta=theta
 		
 		n.cov=matrix(rep(0,n*n), n, n)
-		nodecode=matrix(c(ntips+1,1,1),1,3)
+		nodecode=matrix(c(ntips+1,1),1,2)
 		
 		x <- matrix(0, n, 1)
 		TIPS <- 1:ntips
@@ -78,31 +74,30 @@ OUwie.sim <- function(phy, data=NULL, simmap.tree=FALSE, alpha, sigma.sq, theta0
 		x[ROOT,] <- theta0
 		
 		for(i in 1:length(edges[,1])){
-			anc = edges[i, 2]
-			desc = edges[i, 3]
-			
-			newregime=which(edges[i,5:(k+4)]==1)
-			current=edges[i,4]
+			anc = edges[i,2]
+			desc = edges[i,3]
+			oldtime=edges[i,4]
+			newtime=edges[i,5]
+
+			newregime=which(edges[i,6:(k+5)]==1)
+
 			if(anc%in%nodecode[,1]){
 				start=which(nodecode[,1]==anc)
-				oldtime=nodecode[start,2]
-				oldregime=nodecode[start,3]
+				oldregime=nodecode[start,2]
 			}
 			else{
-				newrow=c(anc,newtime,oldregime)
+				newrow=c(anc,oldregime)
 				nodecode=rbind(nodecode,newrow)
-				oldtime=newtime
 			}
 			if(oldregime==newregime){
-				newtime=current
-				x[edges[i,3],]=x[edges[i,2],]*exp(-alpha[oldregime]*(oldtime-newtime))+(theta[oldregime])*(1-exp(-alpha[oldregime]*(oldtime-newtime)))+sigma[oldregime]*rnorm(1,0,1)*sqrt((1-exp(-2*alpha[oldregime]*(oldtime-newtime)))/(2*alpha[oldregime]))
+				x[edges[i,3],]=x[edges[i,2],]*exp(-alpha[oldregime]*(newtime-oldtime))+(theta[oldregime])*(1-exp(-alpha[oldregime]*(newtime-oldtime)))+sigma[oldregime]*rnorm(1,0,1)*sqrt((1-exp(-2*alpha[oldregime]*(newtime-oldtime)))/(2*alpha[oldregime]))
 			}
 			else{
-				newtime=current+((oldtime-current)/2)
-				epoch1=x[edges[i,2],]*exp(-alpha[oldregime]*(oldtime-newtime))+(theta[oldregime])*(1-exp(-alpha[oldregime]*(oldtime-newtime)))+sigma[oldregime]*rnorm(1,0,1)*sqrt((1-exp(-2*alpha[oldregime]*(oldtime-newtime)))/(2*alpha[oldregime]))
-				oldtime=newtime
-				newtime=current
-				x[edges[i,3],]=epoch1*exp(-alpha[newregime]*(oldtime-newtime))+(theta[newregime])*(1-exp(-alpha[newregime]*(oldtime-newtime)))+sigma[newregime]*rnorm(1,0,1)*sqrt((1-exp(-2*alpha[newregime]*(oldtime-newtime)))/(2*alpha[newregime]))
+				halftime=newtime+((oldtime-newtime)/2)
+				epoch1=x[edges[i,2],]*exp(-alpha[oldregime]*(halftime-oldtime))+(theta[oldregime])*(1-exp(-alpha[oldregime]*(halftime-oldtime)))+sigma[oldregime]*rnorm(1,0,1)*sqrt((1-exp(-2*alpha[oldregime]*(halftime-oldtime)))/(2*alpha[oldregime]))
+				oldtime=halftime
+				newtime=newtime
+				x[edges[i,3],]=epoch1*exp(-alpha[newregime]*(newtime-oldtime))+(theta[newregime])*(1-exp(-alpha[newregime]*(newtime-oldtime)))+sigma[newregime]*rnorm(1,0,1)*sqrt((1-exp(-2*alpha[newregime]*(newtime-oldtime)))/(2*alpha[newregime]))
 			}
 			oldregime=newregime
 		}
@@ -133,11 +128,12 @@ OUwie.sim <- function(phy, data=NULL, simmap.tree=FALSE, alpha, sigma.sq, theta0
 		root.state<-phy$map[[1]]
 		
 		#New tree matrix to be used for subsetting regimes
-		edges=cbind(c(1:(n-1)),phy$edge,phy$edge.length)
+		edges=cbind(c(1:(n-1)),phy$edge,nodeHeights(phy))
+		if(scaleHeight==TRUE){
+			edges[,4:5]<-edges[,4:5]/max(nodeHeights(phy))
+		}
 		edges=edges[sort.list(edges[,3]),]
 		
-		edges[,4]=branch.lengths
-		edges[,4]<-1-edges[,4]
 		#Resort the edge matrix so that it looks like the original matrix order
 		edges=edges[sort.list(edges[,1]),]
 		
@@ -149,7 +145,7 @@ OUwie.sim <- function(phy, data=NULL, simmap.tree=FALSE, alpha, sigma.sq, theta0
 		theta=theta
 		
 		n.cov=matrix(rep(0,n*n), n, n)
-		nodecode=matrix(c(ntips+1,0,1),1,3)
+		nodecode=matrix(c(ntips+1,1),1,2)
 		
 		x <- matrix(0, n, 1)
 		TIPS <- 1:ntips
@@ -160,19 +156,22 @@ OUwie.sim <- function(phy, data=NULL, simmap.tree=FALSE, alpha, sigma.sq, theta0
 			
 			anc = edges[i, 2]
 			desc = edges[i, 3]
-			
-			currentmap<-phy$maps[[i]]
-			current=edges[i,4]
+
+			if(scaleHeight==TRUE){
+				currentmap<-phy$maps[[i]]/max(nodeHeights(phy))
+			}
+			else{
+				currentmap<-phy$maps[[i]]
+			}
+			oldtime=edges[i,4]
 			
 			if(anc%in%nodecode[,1]){
 				start=which(nodecode[,1]==anc)
-				oldtime=nodecode[start,2]
-				oldregime=nodecode[start,3]
+				oldregime=nodecode[start,2]
 			}
 			else{
-				newrow=c(anc,newtime,oldregime)
+				newrow=c(anc,oldregime)
 				nodecode=rbind(nodecode,newrow)
-				oldtime=newtime
 			}
 			if(length(phy$maps[[i]])==1){
 				regimeduration<-currentmap[1]
